file

package
v0.0.0-...-c80a798 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2026 License: GPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsDir

func IsDir(path string) (bool, error)

IsDir checks if the given path is a valid directory

func NewGlob

func NewGlob(pattern string) glob.Glob

NewGlob compiles the given pattern

func ReadDirRecursive

func ReadDirRecursive(path string) ([]string, error)

ReadDirRecursive reads all files from the given path and returns them always in the same lexical order

func Transform

func Transform(patterns *[]string) []glob.Glob

Transform compiles all given patterns to globs and maps them

Types

This section is empty.

Jump to